@@ -316,15 +316,29 @@ class Stack(MixIn):
         Pack and append pkt to .txPkts deque
         Override in subclass
         """
-        pkt.pack()
-        self.txPkts.append(pkt)
+        try:
+            pkt.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing pkt.\n{}\n{}\n".format(self.name, pkt, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+        else:
+            self.txPkts.append(pkt)
 
     def packetize(self, msg):
         """
         Returns packed packet created from msg
         Override in subclass
         """
-        return None
+        packet = packeting.Packet(stack=self, packed=msg.encode('ascii'))
+        try:
+            packet.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing msg.\n{}\n{}\n".format(self.name, msg, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+            return None
+        return packet
 
     def _serviceOneTxMsg(self):
         """
@@ -334,7 +348,7 @@ class Stack(MixIn):
         """
         msg = self.txMsgs.popleft()
         console.verbose("{0} sending\n{1}\n".format(self.name, msg))
-        packet = self.packetize(msg, remote)
+        packet = self.packetize(msg)
         if packet is not None:  # queue packet
             self.txPkts.append(packet)
 
@@ -386,7 +400,15 @@ class Stack(MixIn):
         Returns packet parsed from raw data
         Override in subclass
         """
-        return None
+        packet = packeting.Packet(stack=self)
+        try:
+            packet.parse(raw=raw)
+        except ValueError as ex:
+            emsg = "{}: Error parsing raw.\n{}\n{}\n".format(self.name, raw, ex)
+            console.terse(emsg)
+            self.incState("pkt_parse_error")
+            return None
+        return packet
 
     def _serviceOneReceived(self):
         """
@@ -442,6 +464,7 @@ class Stack(MixIn):
         """
         pkt = self.rxPkts.popleft()
         console.verbose("{0} received packet\n{1}\n".format(self.name, pkt.show()))
+        self.incStat("pkt_received")
         message = self.messagize(pkt)
         if message is not None:
             self.rxMsgs.append(message)
@@ -638,29 +661,36 @@ class RemoteStack(Stack):
         Pack and Append (pkt, ha) duple to .txPkts deque
         Override in subclass
         """
-        pkt.pack()
-        self.txPkts.append((pkt, ha))
+        try:
+            pkt.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing pkt.\n{}\n{}\n".format(self.name, pkt, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+        else:
+            self.txPkts.append((pkt, ha))
 
     def packetize(self, msg, remote=None):
         """
         Returns packed packet created from msg destined for remote
-        Uses zeroth remote if not provided
+        Remote provided if attributes needed to fill in packet
         Override in subclass
         """
-        if remote is None:
-            if not self.remotes:
-                emsg = "No remote to send to.\n"
-                console.terse(emsg)
-                self.incStat("msg_destination_invalid")
-                return
-            remote = self.remotes.values()[0]
-        return None
+        packet = packeting.Packet(stack=self, packed=msg.encode('ascii'))
+        try:
+            packet.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing msg.\n{}\n{}\n".format(self.name, msg, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+            return None
+        return packet
 
     def _serviceOneTxMsg(self):
         """
         Handle one (message, remote) duple from .txMsgs deque
         Assumes there is a duple on the deque
-        Appends (packed, ha) duple to txPkts deque
+        Appends (packet, ha) duple to txPkts deque
         """
         msg, remote = self.txMsgs.popleft()  # duple (msg, destination uid
         console.verbose("{0} sending to {1}\n{2}\n".format(self.name,
@@ -668,7 +698,7 @@ class RemoteStack(Stack):
                                                            msg))
         packet = self.packetize(msg, remote)
         if packet is not None:
-            self.txPkts.append(packet)
+            self.txPkts.append((packet, remote.ha))
 
     def message(self, msg, remote=None):
         """
@@ -686,12 +716,19 @@ class RemoteStack(Stack):
             remote = self.remotes.values()[0]
         self.txMsgs.append((msg, remote))
 
-    def messagize(self, pkt, ha=None):
+    def messagize(self, pkt, ha):
         """
-        Returns messageconverted from packet pkt sourced from ha
+        Returns duple of (message, remote) converted from rx packet pkt and ha
         Override in subclass
         """
-        return None
+        msg = pkt.packed.decode("ascii")
+        try:
+            remote = self.haRemotes[ha]
+        except KeyError as ex:
+            console.verbose(("{0}: Dropping packet received from unknown remote "
+                             "ha '{1}'.\n{2}\n".format(self.name, ha, pkt.packed)))
+            return (None, None)
+        return (msg, remote)
 
     def _serviceOneRxPkt(self):
         """
@@ -702,22 +739,20 @@ class RemoteStack(Stack):
         console.verbose("{0} received packet from {1}\n{2}\n".format(self.name,
                                                                      ha or '',
                                                                      pkt.show()))
-        message = self.messagize(pkt, ha)
-        if message is not None:
-            self.rxMsgs.append(message)
+        self.incStat("pkt_received")
+        message, remote = self.messagize(pkt, ha)
+        if remote:
+            remote.receive(message)
 
     def _serviceOneRxMsg(self):
         """
         Service one duple from .rxMsgs deque
         """
-        msg, remote = self.rxMsgs.popleft()
-        console.verbose("{0}: Servicing RxMsg from {1} at {2:.3f}:"
-                        "\n     {3}\n".format(self.name,
-                                              remote.name,
+        msg = self.rxMsgs.popleft()
+        console.verbose("{0}: Servicing RxMsg at {1:.3f}:"
+                        "\n     {2}\n".format(self.name,
                                               self.stamper.stamp,
                                               msg))
-        if remote:
-            remote.receive(msg)
 
     def serviceTimers(self):
         """
@@ -1393,18 +1428,10 @@ class ClientStreamStack(Stack):
         """
         super(ClientStreamStack, self).__init__(**kwa)
 
-    def packetize(self, msg, remote=None):
-        """
-        Returns packed packet created from msg destined for remote
-        Override in subclass
-        """
-        return packeting.Packet(packed=msg.encode('ascii'))
-
     def _serviceOneTxPkt(self):
         """
         Service one (packet, ha) duple on .txPkts deque
         Packet is assumed to be packed already in .packed
-        Assumes there is a duple on the deque
         Override in subclass
         """
         pkt = None
@@ -1432,7 +1459,15 @@ class ClientStreamStack(Stack):
         Returns packet parsed from raw data
         Override in subclass
         """
-        return packeting.Packet(packed=raw)
+        packet = packeting.Packet(stack=self)
+        try:
+            packet.parse(raw=raw)
+        except ValueError as ex:
+            emsg = "{}: Error parsing raw.\n{}\n{}\n".format(self.name, raw, ex)
+            console.terse(emsg)
+            self.incState("pkt_parse_error")
+            return None
+        return packet
 
     def _serviceOneReceived(self):
         """
@@ -1861,8 +1896,14 @@ class GramStack(Stack):
         Pack and Append (pkt, ha) duple to .txPkts deque
         Override in subclass
         """
-        pkt.pack()
-        self.txPkts.append((pkt, ha))
+        try:
+            pkt.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing pkt.\n{}\n{}\n".format(self.name, pkt, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+        else:
+            self.txPkts.append((pkt, ha))
 
     def _serviceOneTxMsg(self):
         """
@@ -1883,7 +1924,15 @@ class GramStack(Stack):
         Returns packet parsed from raw data sourced from ha
         Override in subclass
         """
-        return None
+        packet = packeting.Packet(stack=self)
+        try:
+            packet.parse(raw=raw)
+        except ValueError as ex:
+            emsg = "{}: Error parsing raw.\n{}\n{}\n".format(self.name, raw, ex)
+            console.terse(emsg)
+            self.incState("pkt_parse_error")
+            return None
+        return packet
 
     def _serviceOneReceived(self):
         '''
@@ -1914,16 +1963,17 @@ class GramStack(Stack):
         packet = self.parserize(raw, ha)
         if packet is not None:
             console.profuse("{0}: received\n    0x{1}\n".format(self.name,
-                                        hexlify(self.rxbs[:packet.size]).decode('ascii')))
+                                        hexlify(raw).decode('ascii')))
             self.rxPkts.append((packet, ha))     # duple = ( packed, source address)
         return True  # received data
 
-    def messagize(self, pkt, ha=None):
+    def messagize(self, pkt, ha):
         """
-        Returns messageconverted from packet pkt sourced from ha
+        Returns duple of (message, remote) converted from rx source packet pkt and rha
         Override in subclass
         """
-        return None
+        msg = pkt.packed.decode("ascii")
+        return (msg, remote)
 
     def _serviceOneRxPkt(self):
         """
@@ -1934,9 +1984,9 @@ class GramStack(Stack):
         console.verbose("{0} received packet from {1}\n{2}\n".format(self.name,
                                                                      ha or '',
                                                                      pkt.show()))
+        self.incStat("pkt_received")
         message = self.messagize(pkt, ha)
-        if message is not None:
-            self.rxMsgs.append(message)
+        self.rxMsgs.append(message)
 
 
 class UdpStack(GramStack, RemoteStack, IpStack):
@@ -2021,13 +2071,6 @@ class UdpStack(GramStack, RemoteStack, IpStack):
                                      bufsize=udping.UDP_MAX_PACKET_SIZE * self.bufcnt)
         return handler
 
-    def packetize(self, msg, remote=None):
-        """
-        Returns packed packet created from msg destined for remote
-        Override in subclass
-        """
-        return packeting.Packet(packed=msg.encode('ascii'))
-
     def transmit(self, pkt, ha=None):
         """
         Pack and Append (pkt, ha) duple to .txPkts deque
@@ -2042,20 +2085,19 @@ class UdpStack(GramStack, RemoteStack, IpStack):
                 self.incStat("pkt_destination_invalid")
                 return
             ha = self.remotes.values()[0].ha
-        pkt.pack()
-        self.txPkts.append((pkt, ha))
 
-
-    def parserize(self, raw, ha=None):
-        """
-        Returns packet parsed from raw data sourced from ha
-        Override in subclass
-        """
-        return packeting.Packet(packed=raw)
+        try:
+            pkt.pack()
+        except ValueError as ex:
+            emsg = "{}: Error packing pkt.\n{}\n{}\n".format(self.name, pkt, ex)
+            console.terse(emsg)
+            self.incState("pkt_pack_error")
+        else:
+            self.txPkts.append((pkt, ha))
 
     def messagize(self, pkt, ha):
         """
-        Returns duple of (message, remote) converted from packet pkt and ha
+        Returns duple of (message, remote) converted from rx source packet pkt and ha
         Override in subclass
         """
         msg = pkt.packed.decode("ascii")
@@ -2064,19 +2106,31 @@ class UdpStack(GramStack, RemoteStack, IpStack):
         except KeyError as ex:
             console.verbose(("{0}: Dropping packet received from unknown remote "
                              "ha '{1}'.\n{2}\n".format(self.name, ha, pkt.packed)))
-            return None
+            return (None, None)
         return (msg, remote)
 
+    def _serviceOneRxPkt(self):
+        """
+        Service pkt from .rxPkts deque
+        Assumes that there is a message on the .rxes deque
+        """
+        pkt, ha = self.rxPkts.popleft()
+        console.verbose("{0} received packet from {1}\n{2}\n".format(self.name,
+                                                                     ha or '',
+                                                                     pkt.show()))
+        self.incStat("pkt_received")
+        message, remote = self.messagize(pkt, ha)
+        if remote:
+            remote.receive(message)
+
     def _serviceOneRxMsg(self):
         """
         Service one duple from .rxMsgs deque
         """
-        msg, remote = self.rxMsgs.popleft()
-        console.verbose("{0}: Servicing RxMsg from {1} at {2:.3f}:"
-                        "\n     {3}\n".format(self.name,
-                                              remote.name,
+        msg = self.rxMsgs.popleft()
+        console.verbose("{0}: Servicing RxMsg at {1:.3f}:"
+                        "\n     {2}\n".format(self.name,
                                               self.stamper.stamp,
                                               msg))
         self.incStat("msg_received")
-        if remote:
-            remote.receive(msg)
+
