@@ -9,17 +9,12 @@ import struct
 from collections import deque
 import inspect
 
+from ..aid.sixing import *
+from ..aid.odicting import odict
 
-from .globaling import *
-from .odicting import odict
-
-from . import aiding
-from . import excepting
-from . import registering
-from . import storing
 from . import acting
 
-from .consoling import getConsole
+from ..aid.consoling import getConsole
 console = getConsole()
 
 class Trait(acting.Actor):
